@@ -1,7 +1,8 @@
 from django.core import management
-from django.core.management import find_commands, find_management_module
+from django.core.management import find_commands
 from django.utils.importlib import import_module
 
+from ..compat import load_management_modules
 
 # A cache of loaded commands, so that call_command
 # doesn't have to reload every time it's called.
@@ -15,34 +16,13 @@ def get_parent_commands():
     This function returns only callback applications above this
     application in the INSTALLED_APPS stack.
     """
-
     global _parent_commands
     if _parent_commands is None:
         django_path = management.__path__
         _parent_commands = dict([(name, 'django.core')
                                  for name in find_commands(django_path[0])])
 
-        # Find the installed apps
-        try:
-            from django.conf import settings
-            apps = settings.INSTALLED_APPS
-        except (AttributeError, EnvironmentError, ImportError):
-            apps = []
-
-        # Find and load the management module for each installed app above
-        # this one.
-        for app_name in apps:
-            try:
-                path = find_management_module(app_name)
-                if path == __path__[0]:
-                    # Found this app
-                    break
-
-                _parent_commands.update(
-                    dict([(name, app_name) for name in find_commands(path)])
-                )
-            except ImportError:
-                pass  # No management module - ignore this app
+        load_management_modules(_parent_commands)
 
         # Reset the Django management cache
         management._commands = None
